gnuastro-commits
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[gnuastro-commits] master 217ad4ff 16/23: color-faint-gray: new name for


From: Mohammad Akhlaghi
Subject: [gnuastro-commits] master 217ad4ff 16/23: color-faint-gray: new name for the script, --bias replaces --brightness
Date: Sun, 24 Dec 2023 22:26:23 -0500 (EST)

branch: master
commit 217ad4ff3cf087c5f2ccc6a4be6abd9ceaf7d681
Author: Mohammad Akhlaghi <mohammad@akhlaghi.org>
Commit: Mohammad Akhlaghi <mohammad@akhlaghi.org>

    color-faint-gray: new name for the script, --bias replaces --brightness
    
    Until now, the script was called 'rgb-faint-gray', but RGB is only one
    format of a color space and would limit us if we wanted to add other color
    spaces like CMYK. Also, the option '--brightness' could be confusing
    because this term has physical meaning in astronomy (although it is
    regularly used in image processing!).
    
    With this commit, the script is now called 'color-faint-gray' and the
    '--brightness' option has been replaced with '--bias'.
---
 README                                             | 10 ++--
 bin/script/Makefile.am                             | 16 +++---
 .../{rgb-faint-gray.sh => color-faint-gray.sh}     | 60 +++++++++++-----------
 doc/gnuastro.texi                                  | 54 +++++++++----------
 tests/Makefile.am                                  |  2 +-
 tests/script/rgb-faint-gray.sh                     |  2 +-
 6 files changed, 72 insertions(+), 72 deletions(-)

diff --git a/README b/README
index 0c2cd4cd..c22d6ea2 100644
--- a/README
+++ b/README
@@ -110,6 +110,11 @@ running a program in a special way), Gnuastro also 
installs Bash scripts
 (all prefixed with 'astscript-'). They can be run like a program and behave
 very similarly (with minor differences, as explained in the book).
 
+  - astscript-color-faint-gray: Given three images for the Red-Green-Blue
+    (RGB) channels, this script will use the bright pixels for color and
+    will show the faint/diffuse regions in grayscale. This greatly helps
+    in visualizing the full dynamic range of astronical data.
+
   - astscript-ds9-region: Given a table (either as a file or from
     standard input), create an SAO DS9 region file from the requested
     positional columns (WCS or image coordinates).
@@ -129,11 +134,6 @@ very similarly (with minor differences, as explained in 
the book).
     various measures (median, sigma-clipped mean and etc), and the radial
     distance can also be measured on any general ellipse.
 
-  - astscript-rgb-faint-gray: Given three images for the Red-Green-Blue
-    (RGB) channels, this script will use the bright pixels for color and
-    will show the faint/diffuse regions in grayscale. This greatly helps
-    in visualizing the full dynamic range of astronical data.
-
   - astscript-sort-by-night: Given a list of FITS files, and a HDU and
     keyword name for a date, this script separates the files in the same
     night (possibly over two calendar days).
diff --git a/bin/script/Makefile.am b/bin/script/Makefile.am
index 18bf03f2..eca9c1c6 100644
--- a/bin/script/Makefile.am
+++ b/bin/script/Makefile.am
@@ -47,7 +47,7 @@ bin_SCRIPTS = astscript-fits-view \
               astscript-psf-subtract \
               astscript-sort-by-night \
               astscript-radial-profile \
-              astscript-rgb-faint-gray \
+              astscript-color-faint-gray \
               astscript-psf-scale-factor \
               astscript-psf-select-stars \
               astscript-pointing-simulate
@@ -61,7 +61,7 @@ EXTRA_DIST = fits-view.sh \
              psf-subtract.sh \
              sort-by-night.sh \
              radial-profile.sh \
-             rgb-faint-gray.sh \
+             color-faint-gray.sh \
              psf-select-stars.sh \
              psf-scale-factor.sh \
              pointing-simulate.sh \
@@ -86,8 +86,8 @@ do_subst = sed -e 's,[@]PREFIX[@],$(exec_prefix),g' \
 
 
 ## Rules to install the scripts.
-astscript-pointing-simulate: pointing-simulate.sh Makefile
-       $(do_subst) < $(srcdir)/pointing-simulate.sh > $@
+astscript-color-faint-gray: color-faint-gray.sh Makefile
+       $(do_subst) < $(srcdir)/color-faint-gray.sh > $@
        chmod +x $@
 
 astscript-ds9-region: ds9-region.sh Makefile
@@ -98,6 +98,10 @@ astscript-fits-view: fits-view.sh Makefile
        $(do_subst) < $(srcdir)/fits-view.sh > $@
        chmod +x $@
 
+astscript-pointing-simulate: pointing-simulate.sh Makefile
+       $(do_subst) < $(srcdir)/pointing-simulate.sh > $@
+       chmod +x $@
+
 astscript-psf-unite: psf-unite.sh Makefile
        $(do_subst) < $(srcdir)/psf-unite.sh > $@
        chmod +x $@
@@ -129,7 +133,3 @@ astscript-sort-by-night: sort-by-night.sh Makefile
 astscript-zeropoint: zeropoint.sh Makefile
        $(do_subst) < $(srcdir)/zeropoint.sh > $@
        chmod +x $@
-
-astscript-rgb-faint-gray: rgb-faint-gray.sh Makefile
-       $(do_subst) < $(srcdir)/rgb-faint-gray.sh > $@
-       chmod +x $@
diff --git a/doc/gnuastro.texi b/doc/gnuastro.texi
index 6be12ff2..e05ed64f 100644
--- a/doc/gnuastro.texi
+++ b/doc/gnuastro.texi
@@ -807,7 +807,7 @@ Pointing pattern simulation
 
 Color images with gray faint regions
 
-* Invoking astscript-rgb-faint-gray::  Details of options and arguments.
+* Invoking astscript-color-faint-gray::  Details of options and arguments.
 
 PSF construction and subtraction
 
@@ -1172,7 +1172,7 @@ This is very useful in testing the coverage of dither 
patterns when designing yo
 (See @ref{Generate radial profile}) Calculate the radial profile of an object 
within an image.
 The object can be at any location in the image, using various measures 
(median, sigma-clipped mean, etc.), and the radial distance can also be 
measured on any general ellipse.
 
-@item astscript-rgb-faint-gray
+@item astscript-color-faint-gray
 (see @ref{Color images with gray faint regions}) Given three images for the 
Red-Green-Blue (RGB) channels, this script will use the bright pixels for color 
and will show the faint/diffuse regions in grayscale.
 This greatly helps in visualizing the full dynamic range of astronical data.
 
@@ -8960,7 +8960,7 @@ In the next section (@ref{Color for bright regions and 
grayscale for faint}), we
 
 In the previous sections we aligned three SDSS images of M51 group @ref{Color 
channels in same pixel grid}, and created a linearly-scaled color image (only 
using @command{astconvertt} program) in @ref{Color image using linear 
transformation}.
 But we saw that showing the brighter and fainter parts of the galaxy in a 
single image is impossible in the linear scale!
-In this section, we will use Gnuastro's @command{astscript-rgb-faint-gray} 
installed script to address this problem and create images which visualize a 
major fraction of the contents of our astronomical data.
+In this section, we will use Gnuastro's @command{astscript-color-faint-gray} 
installed script to address this problem and create images which visualize a 
major fraction of the contents of our astronomical data.
 
 This script aims to solve the problems mentioned in the previous section.
 See Infante-Sainz et al. (2023, which first introduced this script) for 
examples of the final images we will be producing in this tutorial.
@@ -8981,7 +8981,7 @@ However, zero point magnitudes of the J-PLUS images are 
different: 23.43, 23.74,
 Also, the field of view of the J-PLUS Camera is very large and we only need a 
small region to see the M51 galaxy group.
 Therefore, we will crop the regions around the M51 group with a width of 0.35 
degree wide (or 21 arcmin) and put the crops in the same @file{aligned/} 
directory we made before (which contains the inputs to the colored images).
 With all the above information, let's download, crop, and have a look at the 
images to check that everything is fine.
-Finally, let's run @command{astscript-rgb-faint-gray} on the three cropped 
images.
+Finally, let's run @command{astscript-color-faint-gray} on the three cropped 
images.
 
 @example
 ## Download
@@ -9006,7 +9006,7 @@ $ astscript-fits-view aligned/*-jplus.fits
 $ R=aligned/i-jplus.fits
 $ G=aligned/r-jplus.fits
 $ B=aligned/g-jplus.fits
-$ astscript-rgb-faint-gray $R $G $B -g1 --output=m51.pdf
+$ astscript-color-faint-gray $R $G $B -g1 --output=m51.pdf
 @end example
 
 By opening the image, you will notice that it is a color image with a gray 
background, making the M51 group and background galaxies visible together.
@@ -9021,7 +9021,7 @@ With this option, the images are internally transformed 
to have the same pixel u
 Since the magnitude zero points are 23.43, 23.74, 23.74 for the i, r, and g 
images, let's use them in the definition
 
 @example
-$ astscript-rgb-faint-gray $R $G $B -g1 --output=m51.pdf \
+$ astscript-color-faint-gray $R $G $B -g1 --output=m51.pdf \
                            -z23.43 -z23.74 -z23.74
 @end example
 
@@ -9041,7 +9041,7 @@ To keep the command simple, we'll add the zeropoint, 
minimum and HDU of each ima
 $ R="aligned/i-jplus.fits -h1 --zeropoint=23.43 --minimum=0.0"
 $ G="aligned/r-jplus.fits -h1 --zeropoint=23.74 --minimum=0.0"
 $ B="aligned/g-jplus.fits -h1 --zeropoint=23.74 --minimum=0.0"
-$ astscript-rgb-faint-gray $R $G $B --output=m51.pdf
+$ astscript-color-faint-gray $R $G $B --output=m51.pdf
 @end example
 
 In contrast to the previous image, the new PDF (with a minimum value of zero) 
exhibits a better background visualization because it is avoiding negative 
pixels to be shown.
@@ -9051,7 +9051,7 @@ Let's decrease @option{--qbright} by an order of 
magnitude in order to display o
 @c: we need a description of what 'qbright' represents! There is no 
description; it just mentioned as a black box!
 
 @example
-$ astscript-rgb-faint-gray $R $G $B --output=m51-qlow.pdf \
+$ astscript-color-faint-gray $R $G $B --output=m51-qlow.pdf \
                            --qbright=1.290644e-01
 @end example
 
@@ -9060,7 +9060,7 @@ Now, let's decrease @option{--stretch} to show very 
bright pixels in linear scal
 This allows you to reveal fainter regions, such as outer parts of galaxies, 
spiral arms, stellar streams, and similar structures.
 
 @example
-$ astscript-rgb-faint-gray $R $G $B --output=m51-qlow-slow.pdf \
+$ astscript-color-faint-gray $R $G $B --output=m51-qlow-slow.pdf \
                            --qbright=1.290644e-01 --stretch=1.290644e-03
 @end example
 
@@ -9073,7 +9073,7 @@ Let's try using the same value for both (so their ratio 
is unity):
 @c: there is no explanation on why 0.5 was used.
 
 @example
-$ astscript-rgb-faint-gray $R $G $B --output=m51-qs-equal.pdf \
+$ astscript-color-faint-gray $R $G $B --output=m51-qs-equal.pdf \
                            --qbright=0.5 --stretch=0.5
 @end example
 
@@ -9083,7 +9083,7 @@ Having a separate color-map for the fainter parts is 
generally a good thing, but
 To disable this feature, you can use the @option{--coloronly} option:
 
 @example
-$ astscript-rgb-faint-gray $R $G $B --output=m51-coloronly.pdf \
+$ astscript-color-faint-gray $R $G $B --output=m51-coloronly.pdf \
                            --qbright=1.290644e-01 --coloronly
 @end example
 
@@ -9101,7 +9101,7 @@ Looking at the last lines that the script prints, we see 
that the default value
 Let's by decrease it to 70.0 to display fewer regions in color (only the very 
bright regions):
 
 @example
-$ astscript-rgb-faint-gray $R $G $B --output=m51-colorval.pdf \
+$ astscript-color-faint-gray $R $G $B --output=m51-colorval.pdf \
                            --qbright=1.290644e-01 --colorval=70
 @end example
 
@@ -9112,7 +9112,7 @@ It is recomended to experiment with different values 
around the estimated one to
 We will use a value of @option{--colorval=95} (close to the value estimated by 
default 99.7) in what follows
 
 @example
-$ astscript-rgb-faint-gray $R $G $B --output=m51-colorval.pdf \
+$ astscript-color-faint-gray $R $G $B --output=m51-colorval.pdf \
                            --qbright=1.290644e-01 --colorval=95
 @end example
 
@@ -9123,7 +9123,7 @@ By increasing this parameter, more area of the image will 
be displayed as black.
 So, let's increase this parameter to, for example, 85 to increase the faint 
black regions.
 
 @example
-$ astscript-rgb-faint-gray $R $G $B --output=m51-grayval.pdf \
+$ astscript-color-faint-gray $R $G $B --output=m51-grayval.pdf \
                            --qbright=1.290644e-01 --colorval=95 \
                            --grayval=85.0
 @end example
@@ -9136,7 +9136,7 @@ To modify the color balance of the output image, you can 
weigh the three channel
 For example, by using @option{-w1 -w1 -w2}, you give two times more weight to 
the blue channel than to the red and green channels:
 
 @example
-$ astscript-rgb-faint-gray $R $G $B --output=m51-weighted.pdf \
+$ astscript-color-faint-gray $R $G $B --output=m51-weighted.pdf \
                            --qbright=1.290644e-01 --colorval=95 \
                            --grayval=85.0 -w1 -w1 -w2
 @end example
@@ -9167,7 +9167,7 @@ Since we have decided to keep the weights, to keep the 
following commands, simpl
 $ R="aligned/i-jplus.fits -h1 -z23.43 -m0.0 -w1"
 $ G="aligned/r-jplus.fits -h1 -z23.74 -m0.0 -w1"
 $ B="aligned/g-jplus.fits -h1 -z23.74 -m0.0 -w2"
-$ astscript-rgb-faint-gray $R $G $B --output=m51-contrast.pdf \
+$ astscript-color-faint-gray $R $G $B --output=m51-contrast.pdf \
                            --qbright=1.290644e-01 --colorval=95 \
                            --grayval=85.0 --contrast=4
 @end example
@@ -9187,7 +9187,7 @@ Let's have a look by giving two very different values to 
it with the simple loop
 
 @example
 $ for g in 0.3 2.0; do \
-    astscript-rgb-faint-gray $R $G $B --output=m51-gamma-$g.pdf \
+    astscript-color-faint-gray $R $G $B --output=m51-gamma-$g.pdf \
                              --qbright=1.290644e-01 --colorval=95 \
                              --grayval=85.0 --contrast=4 --gamma=$g; \
   done
@@ -9201,7 +9201,7 @@ In this case, the rationale remains the same as explained 
earlier.
 Two additional options are available to smooth different regions by convolving 
with a Gaussian kernel: @option{--colorkernelfwhm} for smoothing color regions 
and @option{--graykernelfwhm} for convolving gray regions.
 The value specified for these options represents the full width at half 
maximum of the Gaussian kernel.
 
-This tutorial provided a general overview of the various options to construct 
a color image from three different FITS images using the 
@command{astscript-rgb-faint-gray} script.
+This tutorial provided a general overview of the various options to construct 
a color image from three different FITS images using the 
@command{astscript-color-faint-gray} script.
 Keep in mind that the optimal parameters for generating the best color image 
depend on your specific goals and the quality of your input images.
 We encourage you to follow this tutorial with the provided J-PLUS images and 
later with your own dataset.
 See @ref{Color images with gray faint regions} for more information, and 
please consider citing Infante-Sainz et al. (2023, @url{TBD}) if you use this 
script in your work (the full Bib@TeX{} entry of this paper will be given to 
you with the @option{--cite} option).
@@ -34283,21 +34283,21 @@ This is because standard color formats like JPEG, 
TIFF or PDF are defined as 8-b
 To solve this issue, it is possible to perform some transformations of the 
images and then obtain the color image.
 
 This is actually what the current script does: it makes some non-linear 
transformations and then uses Gnuastro's ConvertType to generate the color 
image.
-There are several parameters and options in order to change the final output 
that are described in @ref{Invoking astscript-rgb-faint-gray}.
+There are several parameters and options in order to change the final output 
that are described in @ref{Invoking astscript-color-faint-gray}.
 A full tutorial describing this script with actual data is available in 
@ref{Color images with full dynamic range}.
 A general overview of this script will be published in Infante-Sainz et al. 
@url{TBD, 2023}; please cite it if this script proves useful in your research.
 
 @menu
-* Invoking astscript-rgb-faint-gray::  Details of options and arguments.
+* Invoking astscript-color-faint-gray::  Details of options and arguments.
 @end menu
 
-@node Invoking astscript-rgb-faint-gray,  , Color images with gray faint 
regions, Color images with gray faint regions
-@subsection Invoking astscript-rgb-faint-gray
+@node Invoking astscript-color-faint-gray,  , Color images with gray faint 
regions, Color images with gray faint regions
+@subsection Invoking astscript-color-faint-gray
 This installed script will consider several images to combine them into a 
single color image to visualize the full dynamic range.
-The executable name is @file{astscript-rgb-faint-gray}, with the following 
general template:
+The executable name is @file{astscript-color-faint-gray}, with the following 
general template:
 
 @example
-$ astscript-rgb-faint-gray [OPTION...] r.fits g.fits b.fits
+$ astscript-color-faint-gray [OPTION...] r.fits g.fits b.fits
 @end example
 
 @noindent
@@ -34305,15 +34305,15 @@ Examples (for a tutorial, see @ref{Color images with 
full dynamic range}):
 
 @example
 ## Generate a color image from three images with default options.
-$ astscript-rgb-faint-gray r.fits g.fits b.fits --output color.pdf
+$ astscript-color-faint-gray r.fits g.fits b.fits --output color.pdf
 
 ## Generate a color image, consider the minimum value to be zero.
-$ astscript-rgb-faint-gray r.fits g.fits b.fits --minimum=0.0 \
+$ astscript-color-faint-gray r.fits g.fits b.fits --minimum=0.0 \
                       --output=color.jpg
 
 ## Generate a color image considering different weights, minimum values,
 ## zero points, and contrast.
-$ astscript-rgb-faint-gray r.fits g.fits b.fits \
+$ astscript-color-faint-gray r.fits g.fits b.fits \
                       --weights=0.9,1.0,1.1 \
                       --minimum=-0.1,0.0,0.1 \
                       --zeropoints=22.4,25.5,24.6 \
diff --git a/tests/Makefile.am b/tests/Makefile.am
index 31c32787..e94b6623 100644
--- a/tests/Makefile.am
+++ b/tests/Makefile.am
@@ -245,7 +245,7 @@ SCRIPT_TESTS = script/psf-unite.sh \
                script/psf-subtract.sh \
                script/sort-by-night.sh \
                script/radial-profile.sh \
-               script/rgb-faint-gray.sh \
+               script/color-faint-gray.sh \
                script/psf-scale-factor.sh \
                script/psf-select-stars.sh
 
diff --git a/tests/script/rgb-faint-gray.sh b/tests/script/rgb-faint-gray.sh
index edcd74fd..009e9444 100755
--- a/tests/script/rgb-faint-gray.sh
+++ b/tests/script/rgb-faint-gray.sh
@@ -24,7 +24,7 @@
 # Set the variables (the executable is in the build tree). Do the
 # basic checks to see if the executable is made or if the defaults
 # file exists (basicchecks.sh is in the source tree).
-prog=rgb-faint-gray
+prog=color-faint-gray
 execname=../bin/script/astscript-$prog
 
 fits1name=0_mkprofcat2.fits



reply via email to

[Prev in Thread] Current Thread [Next in Thread]
diff --git a/bin/script/rgb-faint-gray.sh b/bin/script/color-faint-gray.sh
similarity index 95%
rename from bin/script/rgb-faint-gray.sh
rename to bin/script/color-faint-gray.sh
index cd4063de..d5b61f11 100644
--- a/bin/script/rgb-faint-gray.sh
+++ b/bin/script/color-faint-gray.sh
@@ -69,16 +69,16 @@ colorkernelfwhm=0
 minvalrange=0.000
 maxvalrange=100.0
 
-# Transformation parameters to improve the contrast and brightness
+# Transformation parameters to improve the contrast and bias
+bias=0.0
 gamma=1.0
 contrast=1.0
-brightness=0.0
 
 quiet=""
 tmpdir=""
 keeptmp=0
 checkparams=0
-output="rgb-faint-gray.jpg"
+output="color-faint-gray.jpg"
 
 coloronly=0
 
@@ -133,10 +133,10 @@ $scriptname options:
   -s, --stretch=FLT       Linear stretching parameter for faint features.
   -Q, --qbright=FLT       Parameter for bringing out brighter features.
 
- Contrast and brightness
-  -b, --brightness        Change the brightness of the final image (linear).
+ Contrast and bias
+  -b, --bias              Constant (bias) to add to all the pixels (linear).
   -c, --contrast          Change the contrast of the final image (linear).
-  -G, --gamma             Gamma parameter (overrides --brightness/--contrast).
+  -G, --gamma             Gamma parameter (nonlinear, overrides bias/contrast).
 
  Color and gray parameters
       --coloronly         No black and grayscale regions.
@@ -265,9 +265,9 @@ do
         -c|--contrast)       contrast="$2";                             
check_v "$1" "$contrast";  shift;shift;;
         -c=*|--contrast=*)   contrast="${1#*=}";                        
check_v "$1" "$contrast";  shift;;
         -c*)                 contrast=$(echo "$1"  | sed -e's/-c//');   
check_v "$1" "$contrast";  shift;;
-        -b|--brightness)     brightness="$2";                           
check_v "$1" "$brightness";  shift;shift;;
-        -b=*|--brightness=*) brightness="${1#*=}";                      
check_v "$1" "$brightness";  shift;;
-        -b*)                 brightness=$(echo "$1"  | sed -e's/-b//'); 
check_v "$1" "$brightness";  shift;;
+        -b|--bias)     bias="$2";                                       
check_v "$1" "$bias";  shift;shift;;
+        -b=*|--bias=*) bias="${1#*=}";                                  
check_v "$1" "$bias";  shift;;
+        -b*)                 bias=$(echo "$1"  | sed -e's/-b//');       
check_v "$1" "$bias";  shift;;
 
         --coloronly)        coloronly=1; shift;;
         --grayval)          grayval="$2";                              check_v 
"$1" "$grayval";  shift;shift;;
@@ -464,7 +464,7 @@ fi
 # set the directory, then make it. This directory will be deleted at
 # the end of the script if the user does not want to keep it (with the
 # `--keeptmp' option).
-defaulttmpdir="rgb-faint-gray-tmp"
+defaulttmpdir="color-faint-gray-tmp"
 if [ x$tmpdir = x ]; then tmpdir=$defaulttmpdir; fi
 if [ -d $tmpdir ]; then junk=1; else mkdir $tmpdir; fi
 
@@ -696,15 +696,15 @@ astarithmetic $I_B $maxRGB / $maxvalrange x 
--output=$I_B_norm $quiet
 
 
 
 # Transformation to change the contrast and brightness
 # ----------------------------------------------------
 #
 # Modify the images that are going to be used for obtaining the COLOR
 # image. There are two possible options: linear and NON-linear
 # transformation. For the linear transformation, two parameters are used,
 # contrast and brightness:
 #
-#  OUTPUT = contrast * INPUT + brightness
+#  OUTPUT = contrast * INPUT + bias
 #
 # In the NON-linear transformation only one parameter is used, gamma:
 #
@@ -725,12 +725,12 @@ if [ x"$gamma" != x"1.0" ]; then
   astarithmetic $I_B_norm $maxvalrange / $gamma pow $maxvalrange x set-t \
                 t t $maxvalrange gt $maxvalrange where 
--output=$I_B_transformed $quiet
 
-elif [ x"$contrast" != x"1.0" ] || [ x$brightness != x"0.0" ]; then
-  astarithmetic $I_R_norm $contrast x $brightness + set-t \
+elif [ x"$contrast" != x"1.0" ] || [ x$bias != x"0.0" ]; then
+  astarithmetic $I_R_norm $contrast x $bias + set-t \
                 t t $maxvalrange gt $maxvalrange where 
--output=$I_R_transformed $quiet
-  astarithmetic $I_G_norm $contrast x $brightness + set-t \
+  astarithmetic $I_G_norm $contrast x $bias + set-t \
                 t t $maxvalrange gt $maxvalrange where 
--output=$I_G_transformed $quiet
-  astarithmetic $I_B_norm $contrast x $brightness + set-t \
+  astarithmetic $I_B_norm $contrast x $bias + set-t \
                 t t $maxvalrange gt $maxvalrange where 
--output=$I_B_transformed $quiet
 
 else
@@ -769,19 +769,19 @@ if [ x$coloronly = x1 ]; then
 # If user wants the gray background image
 else
 
     # Until now, all necessary threshold and parameters have been computed (if
     # the user did not specify any value) from the R,G,B images. The following
     # steps are necessary for constructing the gray background color image. So,
     # low brightness will be showed in gray while high brightness wil be showed
     # in color.
 
     # Convolve the gray threshold image and set it to 0-100 range values
     # ------------------------------------------------------------------
     #
-    # Convolve the image that is going to be used for defining the threshold
-    # for splitting the COLOR and GRAY parts. By doing this, instead of having
-    # a noised frontier, the border would be more clear. If the user don't want
-    # to convolve, just make a symbolic link.
+    # Convolve the image that is going to be used for defining the
+    # threshold for splitting the COLOR and GRAY parts. By doing this,
+    # instead of having a noised frontier, the border would be more
+    # clear. If the user don't want to convolve, just make a symbolic link.
     I_COLORGRAY_threshold="$tmpdir/COLORGRAY_threshold.fits"
     if [ $colorkernelfwhm = 0 ]; then
       # Change pixel values to the wanted range
@@ -927,9 +927,9 @@ else
     # Find the GRAY thresholds
     # ------------------------
     #
-    # Once the COLOR and GRAY parts have been separated, the gray part can be
-    # also separated into BLACK and WHITE. To separate these two parts, here a
-    # threshold is estimated as the median of the GRAY values.
+    # Once the COLOR and GRAY parts have been separated, the gray part can
+    # be also separated into BLACK and WHITE. To separate these two parts,
+    # here a threshold is estimated as the median of the GRAY values.
     I_GRAY_colormasked_clipped="$tmpdir/GRAY_colormasked_clipped.fits"
     grayval_guessed=$(aststatistics $I_GRAY_colormasked --median -q)
 
@@ -696,15 +696,15 @@ astarithmetic $I_B $maxRGB / $maxvalrange x 
 
 
-# Transformation to change the contrast and brightness
-# ----------------------------------------------------
+# Transformation to change the contrast and bias
+# ----------------------------------------------
 #
 # Modify the images that are going to be used for obtaining the COLOR
@@ -696,15 +696,15 @@ astarithmetic $I_B $maxRGB / $maxvalrange x 
 # image. There are two possible options: linear and NON-linear
 # transformation. For the linear transformation, two parameters are used,
-# contrast and brightness:
+# contrast and bias:
 #
@@ -769,19 +769,19 @@ if [ x$coloronly = x1 ]; then
 else
 
-    # Until now, all necessary threshold and parameters have been computed (if
-    # the user did not specify any value) from the R,G,B images. The following
-    # steps are necessary for constructing the gray background color image. So,
-    # low brightness will be showed in gray while high brightness wil be showed
-    # in color.
+    # Until now, all necessary threshold and parameters have been computed
+    # (if the user did not specify any value) from the R,G,B images. The
+    # following steps are necessary for constructing the gray background
+    # color image. So, low bias will be showed in gray while high bias wil
+    # be showed in color.
 
     # Convolve the gray threshold image and set it to 0-100 range values